@@ -24,6 +24,8 @@ C<method sockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
 
 Returns L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object containing a local address and a local port.
 
+The type of the returned value is L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In>.
+
 This method must be implemented by the class that declares this interface.
 
 =head2 peername
@@ -32,6 +34,8 @@ C<method peername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ();>
 
 Returns L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object containing a remote address and a local port.
 
+The type of the returned value is L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In>.
+
 This method must be implemented by the class that declares this interface.
 
 =head2 sockaddr
@@ -74,6 +78,20 @@ C<method peerport : int ();>
 
 Returns a remote port.
 
+=head2 create_sockaddr
+
+C<method create_sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($address : string, $port : int);>
+
+Creates a L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object given the address $address and the port $port.
+
+$address is allowed to be a domain name, a host name, an IP address.
+
+The type of the returned value is L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In>.
+
+Implementation:
+
+This method resolves $address using L<Net::DNS::Native#getaddrinfo|SPVM::Net::DNS::Native/"getaddrinfo"> method in non-blocking way and creates a L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In> object from the resolved IP address and $port.
+
 =head1 Copyright & License
 
 Copyright (c) 2024 Yuki Kimoto
